==> react-bootstrap-0.30.0.jar: META-INF/resources/webjars/react-bootstrap/0.30.0/README.md <==
# React-Bootstrap [![Travis][build-badge]][build] [![npm][npm-badge]][npm]

[Bootstrap 3][bootstrap] components built with [React][react].

[![Coveralls][coveralls-badge]][coveralls]
[![Discord][discord-badge]][discord]
[![Thinkful][thinkful-badge]][thinkful]

__Under active development - APIs will change.__ Check out the [1.0.0 roadmap](https://github.com/react-bootstrap/react-bootstrap/wiki#100-roadmap) and [contributing guidelines][contributing] to see where you can help out. Prior to the 1.0.0 release, deprecations or breaking changes will result in a minor version bump.

## Docs

See the [documentation][documentation] with live editable examples.

## Related modules

- [react-router-bootstrap][react-router-bootstrap] – Integration with [React Router][react-router]

## Local setup

- Install the dependencies with `npm install`
- Run tests `npm test`
- Run tests in watch mode `npm run test-watch`
- Run the docs site in development mode with `npm run docs`. This will watch
  for file changes as you work. Simply refresh the page to see the updates.
- Build with `npm run build`

## Contributions

Yes please! See the [contributing guidelines][contributing] for details.

[bootstrap]: http://getbootstrap.com
[react]: http://facebook.github.io/react/

[documentation]: http://react-bootstrap.github.io
[contributing]: CONTRIBUTING.md

[build-badge]: https://travis-ci.org/react-bootstrap/react-bootstrap.svg?branch=master
[build]: https://travis-ci.org/react-bootstrap/react-bootstrap

[npm-badge]: https://badge.fury.io/js/react-bootstrap.svg
[npm]: http://badge.fury.io/js/react-bootstrap

[react-router-bootstrap]: https://github.com/react-bootstrap/react-router-bootstrap
[react-router]: https://github.com/reactjs/react-router

[thinkful-badge]: https://tf-assets-staging.s3.amazonaws.com/badges/thinkful_repo_badge.svg
[thinkful]: http://start.thinkful.com/react/?utm_source=github&utm_medium=badge&utm_campaign=react-bootstrap

[coveralls-badge]: https://coveralls.io/repos/react-bootstrap/react-bootstrap/badge.svg?branch=master&service=github
[coveralls]: https://coveralls.io/github/react-bootstrap/react-bootstrap?branch=master

[discord-badge]: https://img.shields.io/badge/Discord-Join%20chat%20%E2%86%92-738bd7.svg
[discord]: https://discord.gg/0ZcbPKXt5bXLs9XK

==> react-bootstrap-0.30.3.jar: META-INF/resources/webjars/react-bootstrap/0.30.3/README.md <==
# React-Bootstrap [![Travis][build-badge]][build] [![npm][npm-badge]][npm]

[Bootstrap 3][bootstrap] components built with [React][react].

[![Codecov][codecov-badge]][codecov]
[![Discord][discord-badge]][discord]
[![Thinkful][thinkful-badge]][thinkful]

__Under active development - APIs will change.__ Check out the [1.0.0 roadmap](https://github.com/react-bootstrap/react-bootstrap/wiki#100-roadmap) and [contributing guidelines][contributing] to see where you can help out. Prior to the 1.0.0 release, deprecations or breaking changes will result in a minor version bump.

## Docs

See the [documentation][documentation] with live editable examples.

## Related modules

- [react-router-bootstrap][react-router-bootstrap] – Integration with [React Router][react-router]

## Local setup

- Install the dependencies with `npm install`
- Run tests `npm test`
- Run tests in watch mode `npm run test-watch`
- Run the docs site in development mode with `npm run docs`. This will watch
  for file changes as you work. Simply refresh the page to see the updates.
- Build with `npm run build`

## Contributions

Yes please! See the [contributing guidelines][contributing] for details.

[bootstrap]: http://getbootstrap.com
[react]: http://facebook.github.io/react/

[documentation]: http://react-bootstrap.github.io
[contributing]: CONTRIBUTING.md

[build-badge]: https://travis-ci.org/react-bootstrap/react-bootstrap.svg?branch=master
[build]: https://travis-ci.org/react-bootstrap/react-bootstrap

[npm-badge]: https://badge.fury.io/js/react-bootstrap.svg
[npm]: http://badge.fury.io/js/react-bootstrap

[react-router-bootstrap]: https://github.com/react-bootstrap/react-router-bootstrap
[react-router]: https://github.com/reactjs/react-router

[thinkful-badge]: https://tf-assets-staging.s3.amazonaws.com/badges/thinkful_repo_badge.svg
[thinkful]: http://start.thinkful.com/react/?utm_source=github&utm_medium=badge&utm_campaign=react-bootstrap

[codecov-badge]: https://img.shields.io/codecov/c/github/react-bootstrap/react-bootstrap/master.svg
[codecov]: https://codecov.io/gh/react-bootstrap/react-bootstrap

[discord-badge]: https://img.shields.io/badge/Discord-Join%20chat%20%E2%86%92-738bd7.svg
[discord]: https://discord.gg/0ZcbPKXt5bXLs9XK
